@@ -5,9 +5,6 @@ from scrapy.exceptions import DropItem
 
 class MongoPipeline(object):
     def process_item(self, item, spider):
-        if not self.collection:
-            spider.logger.warn(f'mongodb not collected, ignore save')
-            return item
         my_item = item.deepcopy()
         item_dict = dict(my_item)
         unique_id = item['unique_id']
@@ -18,7 +15,7 @@ class MongoPipeline(object):
         if not crawled_at:
             raise DropItem('crawled_at is None')
 
-        self.collection.update_one({
+        spider.collection.update_one({
             'unique_id':   my_item.get('unique_id')
         }, {"$set": item_dict}, upsert=True)
         return item
